/*******************************************************************************
 * Copyright (c) 2003, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.team.internal.ftp.client;

import java.util.Calendar;
import java.util.GregorianCalendar;
import java.util.NoSuchElementException;
import java.util.StringTokenizer;

import org.eclipse.team.internal.ftp.FTPException;

/**
 * drwxr-xr-x    3 mvalenta     4096 Feb  2  2003 .clanbomber
 */
public class LSDirectoryEntryParserWithUsernameOnly extends LSDirectoryEntryParser {
	
	/* (non-Javadoc)
	 * @see org.eclipse.team.internal.ftp.client.LSDirectoryEntryParser#parseEntry(java.lang.String)
	 */
	public FTPDirectoryEntry parseEntry(String line) throws FTPException {
		boolean hasDirectorySemantics = hasDirectorySementics(line);
		boolean hasFileSemantics = hasFileSementics(line);
		if (!hasFileSemantics && !hasDirectorySemantics) {
			return null;
		}
		StringTokenizer tok = new StringTokenizer(line, " \t"); //$NON-NLS-1$
		try {
			String permissions = tok.nextToken();
			if (permissions.length() != 10) {
				return null;
			}
			long blocks = Long.parseLong(tok.nextToken(), 10);
			String username = tok.nextToken();
			long size = Long.parseLong(tok.nextToken(), 10);
			Calendar calendar = GregorianCalendar.getInstance(Constants.DEFAULT_TIMEZONE);
			String filename = parseDateAndName(tok, calendar);
			if (filename == null) {
				return null;
			}
			
			// done!
			return new FTPDirectoryEntry(filename, hasDirectorySemantics, hasFileSemantics,
				size, calendar.getTime());
		} catch (NoSuchElementException e) {
			// expected more tokens
			return null;
		} catch (NumberFormatException e) {
			// don't understand the format so ignore the line
			return null;
		}
	}
}
