/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.team.internal.ftp.ui.subscriber;

import java.net.URL;

import org.eclipse.core.resources.IContainer;
import org.eclipse.core.resources.IResource;
import org.eclipse.jface.dialogs.IDialogSettings;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.team.core.TeamException;
import org.eclipse.team.internal.ftp.FTPPlugin;
import org.eclipse.team.internal.ftp.Policy;
import org.eclipse.team.internal.ftp.subscriber.*;
import org.eclipse.team.internal.ftp.target.FTPSite;
import org.eclipse.team.internal.target.subscriber.TargetDeploymentProvider;
import org.eclipse.team.internal.target.subscriber.TargetSubscriber;
import org.eclipse.team.internal.ui.ITeamUIImages;
import org.eclipse.team.internal.ui.TeamUIPlugin;
import org.eclipse.team.internal.ui.target.subscriber.ExportWizard;
import org.eclipse.team.internal.ui.target.subscriber.SiteCreationPage;
import org.eclipse.team.ui.synchronize.*;
import org.eclipse.ui.IWorkbench;

public class FTPExportWizard extends ExportWizard {

	protected void initializeDialogSettings() {
		// initializes the dialogs settings store
		IDialogSettings workbenchSettings = FTPPlugin.getPlugin().getDialogSettings();
		IDialogSettings section = workbenchSettings.getSection("FTPExportWizard");//$NON-NLS-1$
		if (section == null) {
			section = workbenchSettings.addNewSection("FTPExportWizard");//$NON-NLS-1$
		}
		setDialogSettings(section);
	}
	
	public String getDeploymentProviderId() {
		return FTPPlugin.DEPLOYMENT_PROVIDER_ID;
	}
	
	protected String getSiteType() {
		return FTPSite.TYPE;
	}
	/* (non-Javadoc)
	 * @see org.eclipse.ui.IWorkbenchWizard#init(org.eclipse.ui.IWorkbench, org.eclipse.jface.viewers.IStructuredSelection)
	 */
	public void init(IWorkbench workbench, IStructuredSelection currentSelection) {
		super.init(workbench, currentSelection);
		setWindowTitle(Policy.bind("FTPExportWizard.5")); //$NON-NLS-1$
	}

	protected TargetDeploymentProvider createDeploymentProvider(URL url) {
		return new FTPDeploymentProvider(url);
	}
	
	protected void setBaseBytes(IContainer container, TargetDeploymentProvider provider) throws TeamException {
		// We know the remote directory exists so update the base in the synchronizer
		((FTPSynchronizer)provider.getSynchronizer()).setBaseBytes(container, FTPSubscriberResource.FOLDER_BYTES);
	}
	
	protected SiteCreationPage createSiteCreationPage() {
		return new FTPSiteCreationPage(
				"ftp-site-creation",  //$NON-NLS-1$
				Policy.bind("FTPMainPage.name"),  //$NON-NLS-1$
				Policy.bind("FTPMainPage.description"),  //$NON-NLS-1$
				TeamUIPlugin.getImageDescriptor(ITeamUIImages.IMG_WIZBAN_SHARE));
	}

	/* (non-Javadoc)
	 * @see org.eclipse.team.internal.ui.target.subscriber.ExportWizard#getSubscriber()
	 */
	public TargetSubscriber getSubscriber() {
		return FTPPlugin.getPlugin().getSubscriber();
	}

	/* (non-Javadoc)
	 * @see org.eclipse.team.internal.ui.target.subscriber.DeploymentWizard#createParticipant()
	 */
	protected SubscriberParticipant createParticipant(ISynchronizeScope scope) {
		return new FTPSynchronizeParticipant(new ResourceScope(new IResource[0]));
	}
}
