/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.team.internal.webdav.subscriber;

import java.util.Iterator;
import java.util.Set;

import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.team.core.TeamException;
import org.eclipse.team.core.variants.IResourceVariant;
import org.eclipse.team.core.variants.ThreeWayRemoteTree;
import org.eclipse.team.internal.core.target.DeploymentProvider;
import org.eclipse.team.internal.target.subscriber.TargetSubscriber;
import org.eclipse.team.internal.webdav.core.Policy;
import org.eclipse.team.internal.webdav.core.TeamWebDavPlugin;
import org.eclipse.webdav.client.AbstractResourceHandle;
import org.eclipse.webdav.client.CollectionHandle;
import org.eclipse.webdav.internal.kernel.DAVException;

public class WebDavRemoteResourceVariantTree extends ThreeWayRemoteTree {

	public WebDavRemoteResourceVariantTree(TargetSubscriber subscriber) {
		super(subscriber);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.team.core.subscribers.helpers.SynchronizationCacheRefreshOperation#getRemoteChildren(org.eclipse.team.core.subscribers.ISubscriberResource, org.eclipse.core.runtime.IProgressMonitor)
	 */
	protected IResourceVariant[] fetchMembers(IResourceVariant remote, IProgressMonitor progress) throws TeamException {
		progress = Policy.monitorFor(progress);
		try {		
			progress.beginTask(Policy.bind("DavRemoteTargetResource.membersProgress", remote.getName()), 100); //$NON-NLS-1$
			progress.subTask(Policy.bind("DavRemoteTargetResource.membersProgress", remote.getName())); //$NON-NLS-1$
			// Only containers have children.
			if (!remote.isContainer())
				return new IResourceVariant[0];
			
			// Query the DAV server to find the children (i.e., members) of the receiver.
			Set remoteChildren;
			try {
				AbstractResourceHandle handle = ((WebDavSubscriberResource)remote).getDavHandle();
				remoteChildren = handle.asCollectionHandle().getMembers();
				progress.worked(80);
			} catch (DAVException exception) {
				// Problem getting the children.
				throw TeamWebDavPlugin.wrapException(exception);
			}
			
			// Have to contruct resource states from DAV resource handles.
			IResourceVariant[] result = new IResourceVariant[remoteChildren.size()];
			int index = 0;
			Iterator remoteChildrenItr = remoteChildren.iterator();
			while (remoteChildrenItr.hasNext()) {
				AbstractResourceHandle remoteChild = (AbstractResourceHandle)remoteChildrenItr.next();
				result[index++] = WebDavSubscriberResource.create(remoteChild, (remoteChild instanceof CollectionHandle));
			}
			progress.worked(20);
			
			// All children processed.
			return result;
		} finally {
			progress.done();
		}
	}

	/* (non-Javadoc)
	 * @see org.eclipse.team.core.subscribers.helpers.SynchronizationCacheRefreshOperation#getRemoteTree(org.eclipse.core.resources.IResource, int, boolean, org.eclipse.core.runtime.IProgressMonitor)
	 */
	protected IResourceVariant fetchVariant(IResource resource, int depth, IProgressMonitor monitor) throws TeamException {
		DeploymentProvider[] providers = TeamWebDavPlugin.getDeploymentManager().getMappings(resource, TeamWebDavPlugin.DEPLOYMENT_PROVIDER_ID);
		if (providers.length == 0) return null;
		return ((WebDavDeploymentProvider)providers[0]).getSubscriberResource(resource);
	}

}
