/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.team.internal.webdav.ui.subscriber;

import java.net.URL;

import org.eclipse.core.resources.IContainer;
import org.eclipse.jface.dialogs.IDialogSettings;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.team.core.TeamException;
import org.eclipse.team.internal.target.subscriber.TargetDeploymentProvider;
import org.eclipse.team.internal.target.subscriber.TargetSubscriber;
import org.eclipse.team.internal.ui.ITeamUIImages;
import org.eclipse.team.internal.ui.TeamUIPlugin;
import org.eclipse.team.internal.ui.target.subscriber.ImportWizard;
import org.eclipse.team.internal.ui.target.subscriber.SiteCreationPage;
import org.eclipse.team.internal.webdav.core.*;
import org.eclipse.team.internal.webdav.subscriber.WebDavDeploymentProvider;
import org.eclipse.team.internal.webdav.ui.WebDavMainPage;
import org.eclipse.team.ui.synchronize.ISynchronizeScope;
import org.eclipse.team.ui.synchronize.SubscriberParticipant;
import org.eclipse.ui.IWorkbench;

public class WebDavImportWizard extends ImportWizard {
	
	/* (non-Javadoc)
	 * @see org.eclipse.ui.IWorkbenchWizard#init(org.eclipse.ui.IWorkbench, org.eclipse.jface.viewers.IStructuredSelection)
	 */
	public void init(IWorkbench workbench, IStructuredSelection currentSelection) {
		super.init(workbench, currentSelection);
	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.jface.wizard.IWizard#getWindowTitle()
	 */
	public String getWindowTitle() {
		return Policy.bind("WebDavImportWizard.5"); //$NON-NLS-1$
	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.team.internal.ui.target.subscriber.ExportWizard#initializeDialogSettings()
	 */
	protected void initializeDialogSettings() {
		// initializes the dialogs settings store
		IDialogSettings workbenchSettings = TeamWebDavPlugin.getPlugin().getDialogSettings();
		IDialogSettings section = workbenchSettings.getSection("ImportWizard");//$NON-NLS-1$
		if (section == null) {
			section = workbenchSettings.addNewSection("ImportWizard");//$NON-NLS-1$
		}
		setDialogSettings(section);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.team.internal.ui.target.subscriber.ExportWizard#createSiteCreationPage()
	 */
	protected SiteCreationPage createSiteCreationPage() {
		return new WebDavMainPage(
				"site-creation",  //$NON-NLS-1$
				Policy.bind("webdavMainPage.name"),  //$NON-NLS-1$
				Policy.bind("webdavMainPage.description"),  //$NON-NLS-1$
				TeamUIPlugin.getImageDescriptor(ITeamUIImages.IMG_WIZBAN_SHARE));
	}

	/* (non-Javadoc)
	 * @see org.eclipse.team.internal.ui.target.subscriber.ExportWizard#getSiteType()
	 */
	protected String getSiteType() {
		return WebDavSite.TYPE;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.team.internal.ui.target.subscriber.ExportWizard#getDeploymentProviderId()
	 */
	public String getDeploymentProviderId() {
		return TeamWebDavPlugin.DEPLOYMENT_PROVIDER_ID;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.team.internal.ui.target.subscriber.ExportWizard#setBaseBytes(org.eclipse.core.resources.IContainer, org.eclipse.team.internal.target.subscriber.TargetDeploymentProvider)
	 */
	protected void setBaseBytes(IContainer container, TargetDeploymentProvider provider) throws TeamException {
		// We know the remote directory exists so update the base in the synchronizer
		// TODO: This may make a remote connection
		provider.getSynchronizer().setBaseBytes(container, (((WebDavDeploymentProvider)provider).getSubscriberResource(container)).asBytes());
	}

	/* (non-Javadoc)
	 * @see org.eclipse.team.internal.ui.target.subscriber.ExportWizard#createDeploymentProvider(java.net.URL)
	 */
	protected TargetDeploymentProvider createDeploymentProvider(URL url) throws TeamException {
		return new WebDavDeploymentProvider(url);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.team.internal.ui.target.subscriber.ExportWizard#getSubscriber()
	 */
	public TargetSubscriber getSubscriber() {
		return TeamWebDavPlugin.getPlugin().getSubscriber();
	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.team.internal.ui.target.subscriber.DeploymentWizard#createParticipant()
	 */
	protected SubscriberParticipant createParticipant(ISynchronizeScope scope) {
		return new WebDavSynchronizeParticipant(scope);
	}
}
